Stan Math Library: File Members

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

- All
- Variables
- Macros

- _
- a
- b
- c
- d
- e
- i
- l
- m
- n
- o
- p
- s
- u
- v
- x
- y

Here is a list of all file members with links to the files they belong to:

### - _ -

- _adjARef : determinant.hpp
- _alloc : mdivide_left_ldlt.hpp , mdivide_left_spd.hpp
- _alloc_ldlt : log_determinant_ldlt.hpp , mdivide_left_ldlt.hpp
- _cols : determinant.hpp
- _impl : trace_gen_quad_form.hpp , trace_inv_quad_form_ldlt.hpp , trace_quad_form.hpp , quad_form.hpp
- _ldlt : trace_inv_quad_form_ldlt.hpp
- _ldltP : mdivide_left_ldlt.hpp
- _llt : mdivide_left_spd.hpp
- _rows : determinant.hpp
- _sym : quad_form.hpp
- _value : trace_inv_quad_form_ldlt.hpp
- _variB : trace_inv_quad_form_ldlt.hpp
- _variD : trace_inv_quad_form_ldlt.hpp
- _variRefA : mdivide_left_tri.hpp , mdivide_left.hpp , mdivide_left_spd.hpp
- _variRefB : mdivide_left_ldlt.hpp , mdivide_left.hpp , mdivide_left_tri.hpp , mdivide_left_spd.hpp
- _variRefC : mdivide_left.hpp , mdivide_left_tri.hpp , mdivide_left_ldlt.hpp , mdivide_left_spd.hpp

### - a -

- A_ : determinant.hpp , mdivide_left.hpp , quad_form.hpp , trace_gen_quad_form.hpp , trace_quad_form.hpp , mdivide_left_tri.hpp
- AinvB_ : trace_inv_quad_form_ldlt.hpp
- alpha_ : log_softmax.hpp , softmax.hpp

### - b -

- B_ : quad_form.hpp , trace_quad_form.hpp , trace_gen_quad_form.hpp

### - c -

- C_ : mdivide_left.hpp , trace_inv_quad_form_ldlt.hpp , quad_form.hpp , mdivide_left_tri.hpp , mdivide_left_spd.hpp , mdivide_left_ldlt.hpp

### - d -

- D_ : trace_gen_quad_form.hpp , trace_inv_quad_form_ldlt.hpp
- Dtype_ : trace_inv_quad_form_ldlt.hpp

### - e -

- exp_val_ : log10.hpp

### - i -

- idx_ : log_softmax.hpp , unit_vector_constrain.hpp , softmax.hpp

### - l -

- length_ : dot_product.hpp , squared_distance.hpp
- likely : likely.hpp

### - m -

- M_ : mdivide_left.hpp , mdivide_left_tri.hpp , mdivide_left_spd.hpp , mdivide_left_ldlt.hpp

### - n -

- N_ : mdivide_left.hpp , mdivide_left_ldlt.hpp , OperandsAndPartials.hpp , mdivide_left_tri.hpp , mdivide_left_spd.hpp
- norm_ : unit_vector_constrain.hpp

### - o -

- operands_ : OperandsAndPartials.hpp

### - p -

- partials_ : OperandsAndPartials.hpp

### - s -

- size_ : dot_self.hpp , log_softmax.hpp , unit_vector_constrain.hpp , softmax.hpp
- softmax_alpha_ : log_softmax.hpp , softmax.hpp
- STAN_MATH_MAJOR : version.hpp
- STAN_MATH_MINOR : version.hpp
- STAN_MATH_PATCH : version.hpp
- STAN_STRING : version.hpp
- STAN_STRING_EXPAND : version.hpp

### - u -

- unit_vector_y_ : unit_vector_constrain.hpp
- unlikely : likely.hpp

### - v -

- v1_ : dot_product.hpp , squared_distance.hpp
- v2_ : squared_distance.hpp , dot_product.hpp
- v_ : dot_self.hpp

### - x -

- xs_ : sort_indices.hpp

### - y -

- y_ : unit_vector_constrain.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.